pub trait PtrPointsToTrait {
type Ptr;
type Target;
// Required methods
spec fn ptr(self) -> *mut Self::Target;
spec fn view_target(self) -> Self::Target;
}Expand description
A verification-only trait that abstracts the permission that tracks both the pointer and the value it points to.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".