RawPtrPerm

Trait RawPtrPerm 

pub trait RawPtrPerm {
    type Ptr;
    type Target;

    // Required methods
    spec fn ptr(self) -> *mut Self::Target;
    spec fn addr(self) -> usize;
}
A verification-only trait that abstracts the permission that can be obtained from a raw pointer.

Required Associated Types

type Ptr

The type of the pointer.

type Target

The type of the value that the pointer points to.

Required Methods

spec fn ptr(self) -> *mut Self::Target

spec fn addr(self) -> usize

Implementors